@@ -13,11 +13,11 @@ from github import Github
 class GitCommittersPlugin(BasePlugin):
 
     config_scheme = (
-        ('enterprise_hostname', config_options.Type(mkdocs_utils.string_types, default='')),
-        ('repository', config_options.Type(mkdocs_utils.string_types, default='')),
-        ('branch', config_options.Type(mkdocs_utils.string_types, default='master')),
-        ('docs_path', config_options.Type(mkdocs_utils.string_types, default='docs/')),
-        ('token', config_options.Type(mkdocs_utils.string_types, default='')),
+        ('enterprise_hostname', config_options.Type(str, default='')),
+        ('repository', config_options.Type(str, default='')),
+        ('branch', config_options.Type(str, default='master')),
+        ('docs_path', config_options.Type(str, default='docs/')),
+        ('token', config_options.Type(str, default='')),
     )
 
     def __init__(self):
@@ -43,26 +43,28 @@ class GitCommittersPlugin(BasePlugin):
     def get_last_commit(self, path):
         since = datetime.now() - timedelta(days=1)
         commits = self.repo.get_commits(path=path, sha=self.branch)
-        last = commits[0]
-        return last
-                    
+        if commits.totalCount > 0:
+            return commits[0]
+        else:
+            return None
+
     def get_committers(self, path):
         seen_committers = []
         unique_committers = []
         commits = self.repo.get_commits( path=path, sha=self.branch )
         for c in commits:
-            if c.committer:
-                if c.committer.login not in seen_committers and c.committer.login != 'web-flow':
-                    seen_committers.append( c.committer.login )
-                    unique_committers.append({
-                        "name": c.committer.name,
-                        "login": c.committer.login,
-                        "avatar": c.committer.avatar_url,
-                        "last_commit": c.committer.avatar_url,
-                        "repos": (self.config['enterprise_hostname'] or 'https://github.com/') + c.committer.login
-                    })
+            if c.author is not None and c.author.login is not None and c.author.login not in seen_committers:
+                seen_committers.append( c.author.login )
+                unique_committers.append({
+                    "name": c.author.name,
+                    "login": c.author.login,
+                    "avatar": c.author.avatar_url,
+                    "last_commit": c.author.avatar_url,
+                    "repos": 'https://' + (self.config['enterprise_hostname'] or 'github.com') + '/\
+' + c.author.login
+                })
         return unique_committers
-                
+
     def on_page_context(self, context, page, config, nav):
         context['committers'] = []
         if not self.enabled:
